## START: Set by rpmautospec
## (rpmautospec version 0.3.5)
## RPMAUTOSPEC: autorelease, autochangelog
%define autorelease(e:s:pb:n) %{?-p:0.}%{lua:
    release_number = 7;
    base_release_number = tonumber(rpm.expand("%{?-b*}%{!?-b:1}"));
    print(release_number + base_release_number - 1);
}%{?-e:.%{-e*}}%{?-s:.%{-s*}}%{!?-n:%{?dist}}
## END: Set by rpmautospec

%global _description %{expand:
Formulaic is a high-performance implementation of Wilkinson formulas for
Python.

It provides:

- high-performance dataframe to model-matrix conversions.
- support for reusing the encoding choices made during conversion of one
  data-set on other datasets.
- extensible formula parsing.
- extensible data input/output plugins, with implementations for:
  - input:
    - pandas.DataFrame
    - pyarrow.Table
  - output:
    - pandas.DataFrame
    - numpy.ndarray
    - scipy.sparse.CSCMatrix
- support for symbolic differentiation of formulas (and hence model matrices).}

Name:           python-formulaic
Version:        0.5.2
Release:        %{autorelease}
Summary:        A high-performance implementation of Wilkinson formulas

# SPDX
License:        MIT
URL:            https://github.com/matthewwardrop/formulaic
Source:         %{url}/archive/v%{version}/%{name}-%{version}.tar.gz
# Backports https://github.com/matthewwardrop/formulaic/commit/e5dedcb0feed39f5ff6e2326d727ca65d247f26d to v0.5.2
# fork lives at https://github.com/sanjayankur31/formulaic/tree/fedora-0.5.2
Patch:          0001-fix-correct-pytest-usage.patch

# Remove pin on sympy given that 1.10.1 fixes the regression that broke
# formulaic.
# https://github.com/matthewwardrop/formulaic/commit/8eb58e85f9f9b4e0dacf8b6478b6a1fb01074daf
Patch:          %{url}/commit/8eb58e85f9f9b4e0dacf8b6478b6a1fb01074daf.patch

# The base package is arched so that the “arrow” extra can be built only on the
# appropriate architectures. There is no compiled code, so there are no debug
# symbols.
%global debug_package %{nil}

%description %_description

%package -n python3-formulaic
Summary:        %{summary}
BuildRequires:  python3-devel
BuildRequires:  python3-pytest
BuildRequires:  python3-sympy
BuildRequires:  git-core

BuildArch:      noarch

%description -n python3-formulaic %_description

%ifarch %{ix86}
# The dependency libarrow is ExcludeArch on 32-bit platforms
%pyproject_extras_subpkg -n python3-formulaic calculus
%else
%pyproject_extras_subpkg -n python3-formulaic arrow calculus
%endif

%prep
%autosetup -n formulaic-%{version} -S git

%generate_buildrequires
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%ifarch %{ix86}
# The dependency libarrow is ExcludeArch on 32-bit platforms
%pyproject_buildrequires -x calculus
%else
%pyproject_buildrequires -x arrow,calculus
%endif

%build
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%pyproject_wheel

%install
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%pyproject_install
%pyproject_save_files formulaic

%check
export SETUPTOOLS_SCM_PRETEND_VERSION=%{version}
%{pytest}

%files -n python3-formulaic -f %{pyproject_files}
%doc README.md

%changelog
* Sun Apr 30 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.5.2-7
- Drop “arrow” extra metapackage on i686

* Sun Apr 30 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.5.2-6
- Confirm License is SPDX MIT

* Sun Apr 30 2023 Benjamin A. Beasley <code@musicinmybrain.net> - 0.5.2-5
- Add missing “arrow” and “calculus” extras metapackages

* Thu Nov 10 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.5.2-4
- chore: check in sources (fix rhbz#2140295)

* Thu Nov 10 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.5.2-3
- feat: backport patch to enable all tests

* Thu Nov 10 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.5.2-2
- feat: ready for review

* Thu Nov 10 2022 Ankur Sinha (Ankur Sinha Gmail) <sanjay.ankur@gmail.com> - 0.5.2-1
- init
